@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+from typing import Any
+
 from plain.assets.finders import APP_ASSETS_DIR
 from plain.internal import internalcode
 from plain.runtime import settings
@@ -11,6 +15,8 @@ class TailwindCSSExtension(InclusionTagExtension):
     tags = {"tailwind_css"}
     template_name = "tailwind/css.html"
 
-    def get_context(self, context, *args, **kwargs):
+    def get_context(
+        self, context: dict[str, Any], *args: Any, **kwargs: Any
+    ) -> dict[str, str]:
         tailwind_css_path = str(settings.TAILWIND_DIST_PATH.relative_to(APP_ASSETS_DIR))
         return {"tailwind_css_path": tailwind_css_path}
